# kaistack.clients.openapi-clients.cluster
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `kaistack.clients.openapi_clients.cluster` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: version not set
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.15
* six >= 1.10
* certifi
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with kaistack.clients.openapi-clients.cluster,
you can run the following:

```python
from __future__ import print_function
import time
import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://localhost
configuration.host = "http://localhost"
# Enter a config with an instance of the API client
with kaistack.clients.openapi_clients.cluster.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = kaistack.clients.openapi_clients.cluster.ClusterServiceApi(api_client)
    
    try:
        api_response = api_instance.get_cluster_config()
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClusterServiceApi->get_cluster_config: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClusterServiceApi* | [**get_cluster_config**](kaistack/clients/openapi_clients/cluster/docs/ClusterServiceApi.md#get_cluster_config) | **GET** /v1/cluster/config | 
*ClusterServiceApi* | [**get_nodes**](kaistack/clients/openapi_clients/cluster/docs/ClusterServiceApi.md#get_nodes) | **GET** /v1/cluster/nodes | 
*ClusterServiceApi* | [**get_system_component**](kaistack/clients/openapi_clients/cluster/docs/ClusterServiceApi.md#get_system_component) | **GET** /v1/cluster/systemstatus | 


## Documentation For Models

 - [CodegenArtifactsStoreConfig](kaistack/clients/openapi_clients/cluster/docs/CodegenArtifactsStoreConfig.md)
 - [CodegenClusterConfig](kaistack/clients/openapi_clients/cluster/docs/CodegenClusterConfig.md)
 - [CodegenGetClusterConfigResponse](kaistack/clients/openapi_clients/cluster/docs/CodegenGetClusterConfigResponse.md)
 - [CodegenGetNodesResponse](kaistack/clients/openapi_clients/cluster/docs/CodegenGetNodesResponse.md)
 - [CodegenGetSystemStatusResponse](kaistack/clients/openapi_clients/cluster/docs/CodegenGetSystemStatusResponse.md)
 - [CodegenNode](kaistack/clients/openapi_clients/cluster/docs/CodegenNode.md)
 - [CodegenSystemComponentDeployment](kaistack/clients/openapi_clients/cluster/docs/CodegenSystemComponentDeployment.md)
 - [CodegenSystemStatus](kaistack/clients/openapi_clients/cluster/docs/CodegenSystemStatus.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




